% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R, R/components.R, R/colormap.R,
%   R/sidebar.R
\name{add_component}
\alias{add_component}
\alias{add_to_sidebar}
\alias{add_colormap}
\alias{add_link}
\alias{add_component,i2dashboard,character-method}
\alias{add_component,i2dashboard,function-method}
\alias{add_component,i2dashboard,gg-method}
\alias{add_component,i2dashboard,gt_tbl-method}
\alias{add_component,i2dashboard,knitr_kable-method}
\alias{add_component,i2dashboard,Heatmap-method}
\alias{add_component,i2dashboard,ANY-method}
\alias{add_link,i2dashboard-method}
\alias{add_colormap,i2dashboard-method}
\alias{add_to_sidebar,i2dashboard-method}
\title{Add content to an i2dashboard object.}
\usage{
add_component(dashboard, component, ...)

add_to_sidebar(dashboard, component, ...)

add_colormap(dashboard, ...)

add_link(dashboard, ...)

\S4method{add_component}{i2dashboard,character}(dashboard, page = "default", component, copy = FALSE, ...)

\S4method{add_component}{i2dashboard,`function`}(dashboard, page = "default", component, ...)

\S4method{add_component}{i2dashboard,gg}(dashboard, component, page = "default", ...)

\S4method{add_component}{i2dashboard,gt_tbl}(dashboard, component, page = "default", ...)

\S4method{add_component}{i2dashboard,knitr_kable}(dashboard, component, page = "default", ...)

\S4method{add_component}{i2dashboard,Heatmap}(dashboard, component, page = "default", ...)

\S4method{add_component}{i2dashboard,ANY}(dashboard, component, page = "default", ...)

\S4method{add_link}{i2dashboard}(
  dashboard,
  href,
  title = NULL,
  icon = NULL,
  align = c("right", "left"),
  target = NULL
)

\S4method{add_colormap}{i2dashboard}(dashboard, map, name)

\S4method{add_to_sidebar}{i2dashboard}(
  dashboard,
  component,
  page = "default",
  global = FALSE,
  copy = FALSE,
  ...
)
}
\arguments{
\item{dashboard}{A \linkS4class{i2dashboard}.}

\item{component}{An R object, function, or string.}

\item{...}{Additional parameters passed to the components render function.}

\item{page}{The name of the page to add the component or sidebar to.}

\item{copy}{Whether or not to copy images to \code{dashboard@datadir}.}

\item{href}{The target of the link.}

\item{title}{The link title.}

\item{icon}{An optional link icon (see https://rmarkdown.rstudio.com/flexdashboard/using.html#icon-sets)}

\item{align}{Optional argument that can be “left” or “right” (defaults = “right”) defining the alignment of the links in the navigation bar}

\item{target}{An optional target (e.g. "_blank")}

\item{map}{A character vector containing colors and possible the levels they map to (as names).}

\item{name}{A name for the color mapping.}

\item{global}{Whether or not to add the content to the global sidebar.}
}
\value{
The (modified) \linkS4class{i2dashboard} object.
}
\description{
Content can be added to the dashboards pages, the sidebar or the navigation bar.
}
\details{
The options to add content in detail:
\itemize{
  \item \strong{\code{add_component}} adds content to a page of the dashboard by evaluating a function, or by including an object, a text or image file.
  \item \strong{\code{add_to_sidebar}} adds content to the dashboards global sidebar or to a pages local sidebar.
  \item \strong{\code{add_link}} adds a link to the navigation bar.
  \item \strong{\code{add_colormap}} adds a global color mapping to the dashboards colormaps.
}

The mechanism to add different types of content to a dashboards page or sidebar depends on the class of the object passed to the function \code{add_component} or \code{add_to_sidebar}:

\itemize{
  \item A function will be evaluated and its return value is used as content.
  \item A string that ends with \code{.md} or \code{.txt} will be used to open a file and use its content.
  \item A string that ends with \code{\\.[png|jpg|jpeg|gif]} will be used to include an image as content.
  \item An R object (e.g. a htmlwidget) will be included if a suitable signature method is implemented.
}
}
